@@ -23,7 +23,7 @@ LOW_CHAR_SAFE = ''.join(chr(n) for n in range(128))
 
 ABSOLUTE_URL_RE = re.compile(r"^https?://", re.I)
 
-ALLOWED_METHODS = ['GET', 'HEAD', 'POST', 'PUT', 'DELETE', 'OPTIONS']
+ALLOWED_METHODS = ['GET', 'HEAD', 'POST', 'PUT', 'DELETE', 'OPTIONS', 'PATCH']
 
 WEBOB_ERROR = (
     "Content-Length is set to -1. This usually mean that WebOb has "
@@ -67,7 +67,11 @@ class HttpClient(object):
         ConnClass = ssl and self.HTTPSConnection or self.HTTPConnection
         uri = ssl and uri[8:] or uri[7:]
         port = ssl and 443 or 80
-        host, path = uri.split('/', 1)
+        try:
+            host, path = uri.split('/', 1)
+        except ValueError:
+            host = uri
+            path = ''
         path = '/' + path
         if ':' in host:
             host, port = host.split(':')
